@@ -3,7 +3,8 @@ use std::ffi::CString;
 use std::ptr;
 
 use crate::{
-  bindgen_runtime::TypeName, check_status, sys, type_of, Callback, Error, Result, Status, ValueType,
+  bindgen_runtime::{TypeName, ValidateNapiValue},
+  check_status, sys, type_of, Callback, Error, Result, Status, ValueType,
 };
 
 #[cfg(feature = "serde-json")]
@@ -85,6 +86,12 @@ impl TypeName for JsSymbol {
   }
 }
 
+impl ValidateNapiValue for JsSymbol {
+  fn type_of() -> Vec<ValueType> {
+    vec![ValueType::Symbol]
+  }
+}
+
 pub struct JsExternal(pub(crate) Value);
 
 impl TypeName for JsExternal {
@@ -669,7 +676,7 @@ impl<'env> NapiRaw for &'env JsUnknown {
 
 impl JsUnknown {
   pub fn get_type(&self) -> Result<ValueType> {
-    unsafe { type_of!(self.0.env, self.0.value) }
+    type_of!(self.0.env, self.0.value)
   }
 
   /// # Safety
